"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useWalletTokensWithMeta = void 0;
const wallet_adapter_react_1 = require("@solana/wallet-adapter-react");
const hooks_1 = require("hooks");
const react_async_hook_1 = require("react-async-hook");
const useUserTokenAccounts_1 = require("./useUserTokenAccounts");
/**
 * Get all tokens in a wallet plus all relevant metadata from spl-token-metadata and spl-token-collective
 *
 * @param owner
 * @returns
 */
function useWalletTokensWithMeta(owner) {
    const { connection } = (0, wallet_adapter_react_1.useConnection)();
    const { result: tokenAccounts, error } = (0, useUserTokenAccounts_1.useUserTokenAccounts)(owner);
    const { tokenCollectiveSdk, loading } = (0, hooks_1.useStrataSdks)();
    const getTokensWithMeta = tokenCollectiveSdk ? tokenCollectiveSdk.getUserTokensWithMeta : () => Promise.resolve([]);
    const asyncResult = (0, react_async_hook_1.useAsync)(getTokensWithMeta, [connection, tokenAccounts]);
    return Object.assign(Object.assign({}, asyncResult), { loading: loading || asyncResult.loading, error: asyncResult.error || error });
}
exports.useWalletTokensWithMeta = useWalletTokensWithMeta;
//# sourceMappingURL=useUserTokensWithMeta.js.map